% pop_loadeep_avg() - Load an averaged ANT EEP file (*.avr). 
%                     (pop out window if no arguments)
%
% Usage:
%   >> [EEG] = pop_loadeep_avg;
%   >> [EEG] = pop_loadeep_avg( filename);
%
% Inputs:
%   filename                   - file name
% 
% Outputs:
%   [EEG]                       - EEGLAB data structure
%
% Note:
% This script is based on pop_loadcnt.m to make it compatible and easy to use in 
% EEGLab.
%
% Author: Maarten-Jan Hoeve, ANT Software, The Netherlands / www.ant-software.nl, 8 October 2003
%
% See also: eeglab(), loadeep_avg()

%123456789012345678901234567890123456789012345678901234567890123456789012

% Copyright (C) 2003 Maarten-Jan Hoeve, ANT Software, The Netherlands, m.hoeve@ieee.org / info@ant-software.nl
%

function [EEG, command]=pop_loadeep_avg(filename); 

command = '';
EEG=[];

if nargin < 1 

	% ask user
	[filename, filepath] = uigetfile('*.AVR;*.avr', 'Choose an averaged ANT EEP file -- pop_loadeep_avg()'); 
    drawnow;
	if filename == 0 return; end;
end;

% load datas
% ----------
EEG = eeg_emptyset;
if exist('filepath')
	fullFileName = sprintf('%s%s', filepath, filename);
else
	fullFileName = filename;
end;	

r = loadeep_avg(fullFileName);

EEG.data            = r.dat;
EEG.filename        = filename;
EEG.filepath        = filepath;
EEG.setname 		= 'Averaged ANT EEP file';
EEG.nbchan          = r.nchannels; 
%EEG.xmin            = (r.xmin-1)/r.rate;
%EEG.xmax           = (r.xmax-1)/r.rate;
EEG.srate           = r.rate;
EEG.pnts            = r.nsmpl;
EEG.chanlocs        = r.chanlocs;
EEG = eeg_checkset(EEG);

command = sprintf('EEG = pop_loadeep_avg(''%s'');',fullFileName); 

return;